@@ -13,6 +13,9 @@ from rlbot.parsing.match_settings_config_parser import boost_amount_mutator_type
     demolish_mutator_types, respawn_time_mutator_types, existing_match_behavior_types
 from rlbot.utils.structures.start_match_structures import MatchSettings, PlayerConfiguration, MutatorSettings
 
+# We pass messages in flatbuffer format to RLBot.exe. In flatbuffer, a signed int field
+# is 32 bit, so it has a max value of 2^31 - 1, in other words 2147483647.
+FLATBUFFER_MAX_INT = 2**31 - 1
 
 class Team(Enum):
     BLUE = 0
@@ -63,7 +66,7 @@ class PlayerConfig:
         player_configuration.human_index = self.human_index or 0
         player_configuration.name = get_sanitized_bot_name(name_dict, self.name)
         player_configuration.team = self.team
-        player_configuration.spawn_id = self.spawn_id or randint(1, 65535)
+        player_configuration.spawn_id = self.spawn_id or randint(1, FLATBUFFER_MAX_INT)
 
         if self.loadout_config:
             self.loadout_config.write(player_configuration)
